instance property
AudioManager
get
instance
A getter to access the single instance of AudioManager.
Implementation
static AudioManager get instance => _instance;
A getter to access the single instance of AudioManager.
static AudioManager get instance => _instance;