EnemyData class

Constructors

EnemyData({required Image image, required int nFrames, required double stepTime, required Vector2 textureSize, required double speedX, required bool canFly})
const

Properties

canFly bool
final
hashCode int
The hash code for this object.
no setterinherited
image Image
final
nFrames int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speedX double
final
stepTime double
final
textureSize → Vector2
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited