AudioManager class
This class is the common interface between DinoRun
and Flame engine's audio APIs.
Properties
Methods
-
init(
List< String> files, Settings settings) → Future<void> -
This method is responsible for initializing caching given list of
files, and initilizing settings. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pauseBgm(
) → void -
playSfx(
String fileName) → void -
resumeBgm(
) → void -
startBgm(
String fileName) → void -
stopBgm(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → AudioManager
-
A getter to access the single instance of AudioManager.
no setter